@@ -1,7 +1,7 @@
 /*
  *  pacman.c
  *
- *  Copyright (c) 2006-2018 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2019 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -177,9 +177,7 @@ static void usage(int op, const char * const myname)
 			printf("%s:\n", str_opt);
 		} else if(op == PM_OP_FILES) {
 			addlist(_("  -l, --list           list the files owned by the queried package\n"));
-			addlist(_("  -o, --owns <file>    query the package that owns <file>\n"));
 			addlist(_("  -q, --quiet          show less information for query and search\n"));
-			addlist(_("  -s, --search <file>  search package file names for matching strings\n"));
 			addlist(_("  -x, --regex          enable searching using regular expressions\n"));
 			addlist(_("  -y, --refresh        download fresh package databases from the server\n"
 			          "                       (-yy to force a refresh even if up to date)\n"));
@@ -196,7 +194,7 @@ static void usage(int op, const char * const myname)
 				addlist(_("      --ignore <pkg>   ignore a package upgrade (can be used more than once)\n"));
 				addlist(_("      --ignoregroup <grp>\n"
 				          "                       ignore a group upgrade (can be used more than once)\n"));
-				/* pass through */
+				/* fall through */
 			case PM_OP_REMOVE:
 				addlist(_("  -d, --nodeps         skip dependency version checks (-dd to skip all checks)\n"));
 				addlist(_("      --assume-installed <package=version>\n"
@@ -241,7 +239,7 @@ static void version(void)
 {
 	printf("\n");
 	printf(" .--.                  Pacman v%s - libalpm v%s\n", PACKAGE_VERSION, alpm_version());
-	printf("/ _.-' .-.  .-.  .-.   Copyright (C) 2006-2018 Pacman Development Team\n");
+	printf("/ _.-' .-.  .-.  .-.   Copyright (C) 2006-2019 Pacman Development Team\n");
 	printf("\\  '-. '-'  '-'  '-'   Copyright (C) 2002-2006 Judd Vinet\n");
 	printf(" '--'\n");
 	printf(_("                       This program may be freely redistributed under\n"
@@ -716,11 +714,6 @@ static int parsearg_upgrade(int opt)
 		return 0;
 	}
 	switch(opt) {
-		case OP_FORCE:
-			pm_printf(ALPM_LOG_WARNING,
-					_("option --force is deprecated; use --overwrite instead\n"));
-			config->flags |= ALPM_TRANS_FLAG_FORCE;
-			break;
 		case OP_OVERWRITE_FILES:
 			parsearg_util_addlist(&(config->overwrite_files));
 			break;
@@ -758,18 +751,10 @@ static int parsearg_files(int opt)
 		return 0;
 	}
 	switch(opt) {
-		case OP_OWNS:
-		case 'o':
-			config->op_q_owns = 1;
-			break;
 		case OP_LIST:
 		case 'l':
 			config->op_q_list = 1;
 			break;
-		case OP_SEARCH:
-		case 's':
-			config->op_s_search = 1;
-			break;
 		case OP_REFRESH:
 		case 'y':
 			(config->op_s_sync)++;
@@ -793,13 +778,8 @@ static int parsearg_files(int opt)
 
 static void checkargs_files(void)
 {
-	if(config->op_q_owns) {
-		invalid_opt(config->op_q_list, "--owns", "--list");
-		invalid_opt(config->op_q_search, "--owns", "--search");
-		invalid_opt(config->op_f_regex, "--owns", "--regex");
-	} else if(config->op_q_list) {
-		invalid_opt(config->op_q_search, "--list", "--search");
-		invalid_opt(config->op_f_regex, "--list", "--regex");
+	if(config->op_q_search) {
+		invalid_opt(config->op_q_list, "--regex", "--list");
 	}
 }
 
@@ -1086,28 +1066,12 @@ static int parseargs(int argc, char *argv[])
  */
 static void cl_to_log(int argc, char *argv[])
 {
-	size_t size = 0;
-	int i;
-	for(i = 0; i < argc; i++) {
-		size += strlen(argv[i]) + 1;
+	char *cl_text = arg_to_string(argc, argv);
+	if(cl_text) {
+		alpm_logaction(config->handle, PACMAN_CALLER_PREFIX,
+				"Running '%s'\n", cl_text);
+		free(cl_text);
 	}
-	if(!size) {
-		return;
-	}
-	char *cl_text = malloc(size);
-	if(!cl_text) {
-		return;
-	}
-	char *p = cl_text;
-	for(i = 0; i < argc - 1; i++) {
-		strcpy(p, argv[i]);
-		p += strlen(argv[i]);
-		*p++ = ' ';
-	}
-	strcpy(p, argv[i]);
-	alpm_logaction(config->handle, PACMAN_CALLER_PREFIX,
-			"Running '%s'\n", cl_text);
-	free(cl_text);
 }
 
 /** Main function.
