@@ -1,7 +1,7 @@
 /*
  *  sync.c
  *
- *  Copyright (c) 2006-2018 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2019 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -222,9 +222,7 @@ static int sync_cleancache(int level)
 					/* skip package databases within the cache directory */
 					"*.db*", "*.files*",
 					/* skip source packages within the cache directory */
-					"*.src.tar.*",
-					/* skip package deltas, we aren't smart enough to clean these yet */
-					"*.delta"
+					"*.src.tar.*"
 				};
 				size_t j;
 
@@ -521,17 +519,24 @@ static int process_pkg(alpm_pkg_t *pkg)
 
 	if(ret == -1) {
 		alpm_errno_t err = alpm_errno(config->handle);
-		if(err == ALPM_ERR_TRANS_DUP_TARGET) {
-			/* just skip duplicate targets */
-			pm_printf(ALPM_LOG_WARNING, _("skipping target: %s\n"), alpm_pkg_get_name(pkg));
-			return 0;
-		} else {
-			pm_printf(ALPM_LOG_ERROR, "'%s': %s\n", alpm_pkg_get_name(pkg),
-					alpm_strerror(err));
+		pm_printf(ALPM_LOG_ERROR, "'%s': %s\n", alpm_pkg_get_name(pkg), alpm_strerror(err));
+		return 1;
+	}
+	config->explicit_adds = alpm_list_add(config->explicit_adds, pkg);
+	return 0;
+}
+
+static int group_exists(alpm_list_t *dbs, const char *name)
+{
+	alpm_list_t *i;
+	for(i = dbs; i; i = i->next) {
+		alpm_db_t *db = i->data;
+
+		if(alpm_db_get_group(db, name)) {
 			return 1;
 		}
 	}
-	config->explicit_adds = alpm_list_add(config->explicit_adds, pkg);
+
 	return 0;
 }
 
@@ -543,6 +548,10 @@ static int process_group(alpm_list_t *dbs, const char *group, int error)
 	int count = alpm_list_count(pkgs);
 
 	if(!count) {
+		if(group_exists(dbs, group)) {
+			return 0;
+		}
+
 		pm_printf(ALPM_LOG_ERROR, _("target not found: %s\n"), group);
 		return 1;
 	}
@@ -813,9 +822,6 @@ int sync_prepare_execute(void)
 		        alpm_strerror(err));
 		switch(err) {
 			case ALPM_ERR_FILE_CONFLICTS:
-				if(config->flags & ALPM_TRANS_FLAG_FORCE) {
-					printf(_("unable to %s directory-file conflicts\n"), "--force");
-				}
 				for(i = data; i; i = alpm_list_next(i)) {
 					alpm_fileconflict_t *conflict = i->data;
 					switch(conflict->type) {
@@ -839,7 +845,6 @@ int sync_prepare_execute(void)
 			case ALPM_ERR_PKG_INVALID:
 			case ALPM_ERR_PKG_INVALID_CHECKSUM:
 			case ALPM_ERR_PKG_INVALID_SIG:
-			case ALPM_ERR_DLT_INVALID:
 				for(i = data; i; i = alpm_list_next(i)) {
 					char *filename = i->data;
 					printf(_("%s is invalid or corrupted\n"), filename);
